# udacity-dsnano-oop
Repository containing code used to complete the exercises for developing a Python package as part of the Udacity Data Science Nanodegree.
# Overview
Python package containing implementations of Gaussian and Binomial distributions.<br />
The package can be installed using `pip install sudoku_R`
# Project Motivation
This project was completed as part of the Data Science Nanodegree on [www.udacity.com](http://www.udacity.com/). The project was completed in a series of excericses designed at getting familiar with writing Object-Oriented Programming code.
The excercises also asked the participant to upload the completed work as a Python package to [www.pypi.org](http://www.pypi.org/). 